<?php
/*
+----------------------------------------------------------------+
|																 |
|	WordPress 2.8 Plugin: WP-PhotoContest 1.0                    |
|	Copyright (c) 2009 Frank van der Stad						 |
|																 |
|	File Written By:											 |
|	- Frank van der Stad										 |
|	- http://www.vanderstad.nl/wp-photocontest									 |
|																 |
|	File Information:											 |
|	- Handles all the photocontest voting and photoshowing		 |
|	- wp-content/plugins/wp-photocontest/viewimg.php			 |
|																 |
+----------------------------------------------------------------+
*/


### Include the configfile
require_once(dirname(__FILE__).'/wp-photocontest-config.php');

### Set some debug vars
if (DEBUG_FLAG == 1)
{
	error_reporting(E_ALL);
	if (!ini_get("display_errors") || ini_get("display_errors")==0)
	{
		ini_set("display_errors", 1);
	} 
}

### Add the lib classes
require_once(dirname(__FILE__).'/lib/debug.func.php');
require_once(dirname(__FILE__).'/lib/php_captcha.class.php');
require_once(dirname(__FILE__).'/lib/thumbnail.class.php');
require_once(dirname(__FILE__).'/lib/wp-photocontest.class.php');
require_once(dirname(__FILE__).'/lib/wp-photocontest.functions.php');

### Add the wordpress-database class
global $wpdb;

### Based on ABSPATH include the wp-config
if ( defined('ABSPATH') )
{
	require_once( ABSPATH . 'wp-config.php');
}
else
{
    require_once('../../../wp-config.php');
    require_once('../../../wp-includes/wp-db.php');
}

### Add the scriptfiles to the header
$myScripts = array('jquery','jquery-form','wp-photocontest.js','swfobject2.js','common.js','validation.js','vote.js','enter.js');
foreach ($myScripts as $myScript)
{
	if (ereg(".js",$myScript))
	{
		$myScriptUrl = WP_PLUGIN_URL . '/wp-photocontest/js/'.$myScript;
		$myScriptFile = WP_PLUGIN_DIR . '/wp-photocontest/js/'.$myScript;
		if ( file_exists($myScriptFile) ) {
			wp_register_script($myScript.'-script', $myScriptUrl);
			wp_enqueue_script($myScript.'-script');	
		}
	}
	else
	{
		wp_enqueue_script($myScript,'',array(),false,false);
	}
}


### Add the stylesheets to the header
$myStyles = array('skins/'.CONTESTS_SKIN.'/theme.css');
foreach ($myStyles as $myStyle)
{
	$myStyleUrl = WP_PLUGIN_URL . '/wp-photocontest/'.$myStyle;
	$myStyleFile = WP_PLUGIN_DIR . '/wp-photocontest/'.$myStyle;
	if ( file_exists($myStyleFile) ) {
		wp_register_style($myStyle.'-Style', $myStyleUrl);
		wp_enqueue_style($myStyle.'-Style');	
	}
}

if (!isset($_COOKIE['photocontestVote']))
{
	$pc_cookie = (string) $wpdb->get_var( $wpdb->prepare( "SELECT UUID() as unique_id"));
	$prexpire = mktime() + 86400 * 50;
	setcookie('photocontestVote',$pc_cookie,$prexpire);
}
else
{
	$pc_cookie = $_COOKIE['photocontestVote'];
}

##############################
### Get the page variables ###
##############################
### Variables
$checkArray = 	array(
					"post_id"=>"",
					"prid"=>"",
					"p"=>"",
					"order"=>"",
					"img_id"=>"",
					"voter_email"=>"",
					"vote"=>"",
					"captcha"=>"",
					"action"=>""
				);

$_REQUEST = array_merge($checkArray,$_REQUEST);
$post_id	= wppc_checkInteger($_REQUEST['post_id']);
$post_id	= wppc_checkInteger($_REQUEST['prid'],$post_id);
$p 			= wppc_checkInteger($_REQUEST['p']);
$order		= wppc_checkOptions($_REQUEST['order'],array('chrono','most_voted','most_viewed','recent'),'chrono');
$img_id		= wppc_checkInteger($_REQUEST['img_id'],1);
$emailadres = is_email($_REQUEST['voter_email']);
$vote 		= wppc_checkInteger($_REQUEST['vote']);
$captcha	= wppc_checkAlphaNum($_REQUEST['captcha']);


### Check if we have a valid user [uncomment this if your want the viewing only for subscribers]
/*if (is_user_logged_in())
{
	get_currentuserinfo();	
}
else 
{
	if ( (!empty($_COOKIE[AUTH_COOKIE]) &&	!wp_validate_auth_cookie($_COOKIE[AUTH_COOKIE])) ||	(empty($_COOKIE[AUTH_COOKIE])) ) 
	{
		nocache_headers();
		wp_redirect(get_option('siteurl') . '/wp-content/plugins/wp-photocontest/login.php?post_id='.$post_id.'&redirect_to=' .urlencode(get_option('siteurl').'/wp-content/plugins/wp-photocontest/view.php?post_id='.$post_id));
		exit();
	}
}*/

### Set the upload directory and get the contest details
$upload_directory = ''; 
if ($post_id != NULL)
{
	$contest_details 				= (array) $wpdb->get_row( $wpdb->prepare( "SELECT contest_id, post_id, start_date, end_date, upload_date, max_photos, contest_path, contest_name, num_photo, intro_text FROM ".$wpdb->prefix."photocontest_admin WHERE post_id = %d", $post_id) );

	if (count($contest_details)<=0)
	{
		$notice_string = '<div class="error">';
		$notice_string .= '<h3>'.__('Error:', 'wp-photocontest').'</h3>';
		$notice_string .= '<BR />';			
		$notice_string .= __('No details for this contest id', 'wp-photocontest');
		$notice_string .= '<BR />';	
		$notice_string .= '</div><BR />';	
	}
	$upload_directory	= dirname(__FILE__)."/".CONTESTS_PATH."/".$contest_details['contest_path'];
	$photo_contest_id	= $contest_details['contest_id'];
	$post_id			= $contest_details['post_id'];
	$contest_id 		= $contest_details['contest_id'];
	$contest_name		= $contest_details['contest_name'];
	$contest_path		= $contest_details['contest_path'];
	$intro_text			= $contest_details['intro_text'];
	$num_photo  		= $contest_details['num_photo'];	
	$start_date   		= $contest_details['start_date'];
	$upload_date   		= $contest_details['upload_date'];	
	$end_date   		= $contest_details['end_date'];	
	$max_photos   		= $contest_details['max_photos'];	
}
else
{
	$notice_string = '<div class="error">';
	$notice_string .= '<h3>'.__('Error:', 'wp-photocontest').'</h3>';
	$notice_string .= '<BR />';			
	$notice_string .= __('No contest id given', 'wp-photocontest');
	$notice_string .= '<BR />';	
	$notice_string .= '</div><BR />';	
}

##############################
### Get the page content   ###
##############################
$image_details		= (array) $wpdb->get_row( $wpdb->prepare("SELECT contest_id, wp_uid, img_id, img_path, img_name, img_title, img_comment, sum_votes, img_view_count, insert_time FROM ".$wpdb->prefix."photocontest WHERE img_id = %d", $img_id));	

// today is??
$today = date('Y-m-d');

//set the cookie and form elements to null
$capthcadata        = NULL;
$captchatext        = NULL;
$vote_result_string = NULL;
$check_vote         = NULL;

####################################
### Do some checks (where are we ###
####################################


//Show the photo, form and captcha
if ( empty($vote) && empty($action) && empty($captcha) )
{
	if ($today > substr($end_date, 0, 10))
	{
		$notice_string = '<div class="error">';
		$notice_string .= '<h3>'.__('Error:', 'wp-photocontest').'</h3>';
		$notice_string .= __('This contest is closed!', 'wp-photocontest');
		$notice_string .= '<BR />';	
		$notice_string .= '</div><BR />';
	} 
	elseif( $today < substr($start_date, 0, 10))
	{
		$notice_string = '<div class="error">';
		$notice_string .= '<h3>'.__('Error:', 'wp-photocontest').'</h3>';
		$notice_string .= __('This contest has not started yet!', 'wp-photocontest');
		$notice_string .= '<BR />';	
		$notice_string .= '</div><BR />';
	}
	else
	{
		$r3a	= (array) $wpdb->get_results( $wpdb->prepare( "SELECT vote FROM ".$wpdb->prefix."photocontest_votes WHERE img_id= %d AND voter_id = %s", $img_id , $pc_cookie) );
		$captcha_insert = count($r3a);
		
		$captcha = new phpCaptcha();
		$capthcadata=$captcha->create(CONTESTS_PATH."/".$contest_path);
		$captchatext=$captcha->getResultStr();	
		//Nog geen vote in de database.
		if ($captcha_insert == 0)
		{	
			$insert_captcha = 	$wpdb->insert
								(	
									$wpdb->prefix.'photocontest_votes',
									array(
										'img_id' => $img_id,
										'voter_id' => $pc_cookie,
										'vote' => 0,
										'captcha_text' => $captchatext
									), 
									array(
										'%d', '%s', '%d', '%s'
									)
								);
			//Add an view to the image
			$add_a_view =		$wpdb->update
								(
									$wpdb->prefix.'photocontest_votes',
									array( 'img_view_count' => 'img_view_count+1'),
									array( 'img_id' => $img_id)
								);	
		}	
		else
		{
			$update_captcha = 	$wpdb->update
								(
									$wpdb->prefix.'photocontest_votes',
									array( 'captcha_text' => $captchatext),
									array( 'img_id' => $img_id, 'voter_id' => $pc_cookie)
								);	
		}					  		
	}
}
else
{
	//Closed contest:
	if ($today > substr($end_date, 0, 10))
	{
		$vote_result_string = '<div class="error">';
		$vote_result_string .= '<h3>'.__('Error:', 'wp-photocontest').'</h3>';
		$vote_result_string .= __('This contest is closed!', 'wp-photocontest');
		$vote_result_string .= '<BR />';	
		$vote_result_string .= '</div><BR />';
	} 
	elseif( $today < substr($start_date, 0, 10))
	{
		$vote_result_string = '<div class="error">';
		$vote_result_string .= '<h3>'.__('Error:', 'wp-photocontest').'</h3>';
		$vote_result_string .= __('This contest has not started yet!', 'wp-photocontest');
		$vote_result_string .= '<BR />';	
		$vote_result_string .= '</div><BR />';
	} 
	elseif (empty($emailadres))
	{
		$vote_result_string = '<div class="error">';
		$vote_result_string .= '<h3>'.__('Error:', 'wp-photocontest').'</h3>';
		$vote_result_string .= __('You have provided an invalid emailadress.', 'wp-photocontest');
		$vote_result_string .= '<BR />';		
		$vote_result_string .= '</div><BR />';	
	}
	else
	{	
		$email_check	= (int) $wpdb->get_var( $wpdb->prepare( "SELECT vote FROM ".$wpdb->prefix."photocontest_votes WHERE img_id= %d  AND voter_email = %s  AND voter_email!=''", $img_id , $emailadres) );

		if ($email_check>0)
		{
			$vote_result_string = '<div class="error">';
			$vote_result_string .= '<h3>'.__('Error:', 'wp-photocontest').'</h3>';
			$vote_result_string .= __('You alreay voted with this emailadress.', 'wp-photocontest');
			$vote_result_string .= '<BR />';		
			$vote_result_string .= '</div><BR />';
		}
		else
		{
			$cookie_check	= (array) $wpdb->get_row ( $wpdb->prepare( "SELECT vote,captcha_text FROM ".$wpdb->prefix."photocontest_votes WHERE img_id= %d AND voter_id = %s", $img_id , $pc_cookie) );
			$captcha_text	= $cookie_check['captcha_text'];
			$cookie_vote	= $cookie_check['vote'];

			if ($cookie_vote > 0)
			{
				$vote_result_string = '<div class="error">';
				$vote_result_string .= '<h3>'.__('Error:', 'wp-photocontest').'</h3>';
				$vote_result_string .= __('You alreay voted.', 'wp-photocontest');
				$vote_result_string .= '<BR />';		
				$vote_result_string .= '</div><BR />';
			}
			else
			{
				if ($captcha_text != $captcha)
				{
					$vote_result_string = '<div class="error">';
					$vote_result_string .= '<h3>'.__('Error:', 'wp-photocontest').'</h3>';
					$vote_result_string .= __('The code you entered incorrect.', 'wp-photocontest');
					$vote_result_string .= '<BR />';
					$vote_result_string .= sprintf(__('The correct tekst was %1$s while you typed %2$s.', 'wp-photocontest'),$captcha_text,wppc_checkString($captcha));
					$vote_result_string .= '<BR />';
					$vote_result_string .= sprintf(__('<a href=\'%1$s?img_id=%2$d&post_id=%3$d&order=%4$s\'>Try it again</a>', 'wp-photocontest'),$_SERVER['PHP_SELF'],$img_id,$post_id,$order);
					$vote_result_string .= '<BR />';					
					$vote_result_string .= '</div><BR />';	
				}
				else 
				{
					if ($vote <= 10 && $vote >= 1)
					{
						$q5 =	$wpdb->update
								(
									$wpdb->prefix.'photocontest_votes',
									array( 'vote' => $vote, 'voter_email' => $emailadres ),
									array( 'img_id' => $img_id, 'voter_id' => $pc_cookie)
								);					
						$r12	= (array) $wpdb->get_row( $wpdb->prepare( "SELECT SUM(vote) AS sum_votes FROM ".$wpdb->prefix."photocontest_votes WHERE img_id= %d", $img_id) );
						$q13 = 	$wpdb->update
								(
									$wpdb->prefix.'photocontest',
									array( 'sum_votes' => $r12['sum_votes']),
									array( 'img_id' => $img_id)
								);							
						$vote_result_string = '<div class="updated">';
						$vote_result_string .= __('Thanks for voting for this photo.', 'wp-photocontest');
						$vote_result_string .= '<BR />';
						$vote_result_string .= '</div><BR />';						
					}
					else
					{
						$vote_result_string = '<div class="error">';
						$vote_result_string .= '<h3>'.__('Error:', 'wp-photocontest').'</h3>';
						$vote_result_string .= __('The vote must be a number between 1 and 10.', 'wp-photocontest');
						$vote_result_string .= '<BR />';
						$vote_result_string .= sprintf(__('<a href=\'%1$s?img_id=%2$d&post_id=%3$d&order=%4$s\'>Try it again</a>', 'wp-photocontest'),$_SERVER['PHP_SELF'],$img_id,$post_id,$order);
						$vote_result_string .= '<BR />';					
						$vote_result_string .= '</div><BR />';						
					}
				}
			}
		}
	}
}

$wppc_prp 			= new photoContest();
$large_thumb	= preg_replace("/".$image_details['img_name']."/", VIEWIMG_BOX."_".$image_details['img_name'], $image_details['img_path']);
$page_menu 		= $wppc_prp->get_top_menu(get_option("siteurl"), $post_id);

##############################
### Get the page content   ###
##############################
ob_start();
?>
<div id="post-<?php echo $post_id;?>" class="post-<?php echo $post_id;?> page">
	<h2><?php echo $contest_details['contest_name'];?></h2>
	<div class="entry">
		<br clear="all" />
		<p><?php echo $page_menu;?></p>
		<br clear="all" />
		<?php
		if ($notice_string != null)
		{
			echo $notice_string;
		}
		else
		{
			?>
			<div id="vote">
				<div class="wp-photocontest_detailslist">			
					<span class="wp-photocontest_details wp-photocontest_details_text">
						<h2 class="wp-photocontest_detailstitle"><?php _e('Photo', 'wp-photocontest');?></h2>
						<div class="wp-photocontest_detailstext">
							<img src="<?php echo get_option("siteurl");?><?php echo $large_thumb;?>">
						</div>									
					</span>
					<span class="wp-photocontest_details wp-photocontest_details_text">
						<h2 class="wp-photocontest_detailstitle"><?php _e('Photo details', 'wp-photocontest');?></h2>
						<div class="wp-photocontest_detailstext">
							<table class="sTable">
								<tr>
									<td class="firstCol"><?php _e('Title', 'wp-photocontest');?>:</td>
									<td class="secondCol">&nbsp;</td>
									<td class="otherCol"><?php echo $image_details['img_title'];?></td>
								</tr>
								<tr>
									<td class="firstCol"><?php _e('Poster', 'wp-photocontest');?>:</td>
									<td class="secondCol">&nbsp;</td>
									<td class="otherCol"><?php echo get_author_name($image_details['wp_uid']);?></td>
								</tr>													
								<tr>
									<td class="firstCol"><?php _e('Date', 'wp-photocontest');?>:</td>
									<td class="secondCol">&nbsp;</td>
									<td class="otherCol"><?php printf(__('on %1$s at %2$s', 'wp-photocontest'),wppc_niceDateTime($image_details['insert_time'],'date'),wppc_niceDateTime($image_details['insert_time'],'time'));?></td>
								</tr>
								<tr>
									<td class="firstCol" valign="top"><?php _e('Description', 'wp-photocontest');?></td>
									<td class="secondCol">&nbsp;</td>
									<td class="otherCol"><?php echo $image_details['img_comment'];?></td>
								</tr>
							</table>
						</div>									
					</span>
					<span class="wp-photocontest_details wp-photocontest_details_text">
						<h2 class="wp-photocontest_detailstitle"><?php _e('Rate this picture', 'wp-photocontest');?></h2>
						<div class="wp-photocontest_detailstext">							
						<?php
						if ($vote_result_string != null)
						{
							echo $vote_result_string;
						}
						else
						{
							if ($check_vote != null)
							{
								$vote_result_string = '<div class="updated">';
								$vote_result_string .= __('Vote already saved!', 'wp-photocontest');
								$vote_result_string .= '<BR />';						
								$vote_result_string .= sprintf(__('on %1$s at %2$s', 'wp-photocontest'),wppc_niceDateTime($r4['vote_time'],'date'),wppc_niceDateTime($r4['vote_time'],'time'));
								$vote_result_string .= '<BR />';
								$vote_result_string .= '</div><BR />';
								echo $vote_result_string;
							}
							else
							{			
								?>	
								<form action="<?php echo $_SERVER['PHP_SELF'];?>" method="post" id="photocontest-vote_form"> 
									<input type="hidden" name="img_id" value="<?php echo $img_id;?>">
									<input type="hidden" name="post_id" value="<?php echo $post_id;?>">										
									<input type="hidden" name="vote" id="vote" value="1" />
									<table class="sTable">
										<tr>
											<td class="firstCol"><?php _e('Email', 'wp-photocontest');?>:</td>
											<td class="secondCol">&nbsp;</td>
											<td class="otherCol">
											<div class="feedback hidden" id="error_voter_email"></div>
											<input type="text" id="voter_email" name="voter_email" size="26" value="">
											</td>
										</tr>
										<!--
										<tr>
											<td class="firstCol"><?php _e('Photo details', 'wp-photocontest');?>Your vote:</td>
											<td class="secondCol">&nbsp;</td>																			
											<td class="otherCol">
												<div class="feedback hidden" id="error_vote"></div>
												<select name="vote">
													<?php 
													for ($i=1;$i<11;$i++)
													{
														echo "<option label='".$i."'>".$i."</option>";
													} 
													?>
												</select>
											</td>
										</tr>
										-->																		
										<tr>
											<td class="firstCol"><?php _e('Capthca', 'wp-photocontest');?>:</td>
											<td class="secondCol">&nbsp;</td>																			
											<td class="otherCol">
											<div class="feedback hidden" id="error_captcha"></div>
											<img src="<?php echo $capthcadata;?>" align="left" />&nbsp;&nbsp;&nbsp;&nbsp;<input type="text" name="captcha" id="captcha" size="5">
											</td>
										</tr>
										<tr>
											<td class="firstCol"></td>
											<td class="secondCol">&nbsp;</td>																			
											<td class="otherCol"><input type="submit" name="action" value="<?php _e('send', 'wp-photocontest');?>"></td>
										</tr>								
									</table>
								</form>									
								<?php
							}
						}
						?>
						</div>
					</span>	
				</div>
			</div>
		<?php
		}
		?>								
	</div>
</div>
<?php
$wp_photocontest_content = ob_get_clean();
if (!empty($vote_result_string))
{
	print($wp_photocontest_content);
}
else
{
	$template_data = wppc_getTemplate();
	$output = str_replace("[WP-PHOTOCONTEST CONTENT]", $wp_photocontest_content, $template_data);
	print($output);	
}
?>	